@@ -421,7 +421,8 @@ static void comm_receive(const unsigned char *bufptr, size_t size)
 			checksum += bufptr[i];
 		}
 		checksum = checksum % 256;
-		upsdebugx(4, "%s: calculated checksum = 0x%02x, bufptr[23] = 0x%02x", __func__, checksum, bufptr[23]);
+		upsdebugx(4, "%s: calculated checksum = 0x%02x, bufptr[23] = 0x%02x",
+			__func__, (unsigned int)checksum, bufptr[23]);
 
 		/* Only proceed if checksum matches and packet delimiter is found */
 		if (checksum == bufptr[23] && bufptr[24] == 254) {
@@ -659,19 +660,25 @@ static void get_updated_info(void)
 
 static int instcmd(const char *cmdname, const char *extra)
 {
+	/* May be used in logging below, but not as a command argument */
+	NUT_UNUSED_VARIABLE(extra);
+	upsdebug_INSTCMD_STARTING(cmdname, extra);
+
 	/* Power-cycle UPS */
 	if (!strcasecmp(cmdname, "shutdown.return")) {
+		upslog_INSTCMD_POWERSTATE_CHANGE(cmdname, extra);
 		ser_send_char(upsfd, CMD_SHUTRET);	/* 0xDE */
 		return STAT_INSTCMD_HANDLED;
 	}
 
 	/* Power-off UPS */
 	if (!strcasecmp(cmdname, "shutdown.stayoff")) {
+		upslog_INSTCMD_POWERSTATE_CHANGE(cmdname, extra);
 		ser_send_char(upsfd, CMD_SHUT);	/* 0xDD */
 		return STAT_INSTCMD_HANDLED;
 	}
 
-	upslogx(LOG_NOTICE, "instcmd: unknown command [%s] [%s]", cmdname, extra);
+	upslog_INSTCMD_UNKNOWN(cmdname, extra);
 	return STAT_INSTCMD_UNKNOWN;
 }
 
@@ -754,6 +761,9 @@ void upsdrv_updateinfo(void)
  */
 void upsdrv_shutdown(void)
 {
+	/* Only implement "shutdown.default"; do not invoke
+	 * general handling of other `sdcommands` here */
+
 	if (!line_unpowered) {	/* on line */
 		upslogx(LOG_NOTICE, "On line, sending power cycle command...");
 		ser_send_char(upsfd, CMD_SHUTRET);
